package com.ruoyi.ss.model.service;


import com.ruoyi.iot.domain.IotDeviceInfo;
import com.ruoyi.ss.model.domain.SmModelBO;
import com.ruoyi.ss.model.domain.SmModelQuery;
import com.ruoyi.ss.model.domain.SmModelVO;

import java.util.List;

/**
 * 型号列表Service接口
 *
 * @author 邱贞招
 * @date 2024-02-21
 */
public interface ModelService
{
    /**
     * 查询型号列表
     *
     * @param modelId 型号列表主键
     * @return 型号列表
     */
    public SmModelVO selectSmModelByModelId(Long modelId);

    /**
     * 查询型号列表列表
     *
     * @param smModel 型号列表
     * @return 型号列表集合
     */
    public List<SmModelVO> selectSmModelList(SmModelQuery smModel);

    /**
     * 新增型号列表
     *
     * @param smModel 型号列表
     * @return 结果
     */
    public int insertSmModel(SmModelBO smModel);

    /**
     * 修改型号列表
     *
     * @param smModel 型号列表
     * @return 结果
     */
    public int updateSmModel(SmModelBO smModel);

    /**
     * 批量删除型号列表
     *
     * @param modelIds 需要删除的型号列表主键集合
     * @return 结果
     */
    public int deleteSmModelByModelIds(Long[] modelIds);

    /**
     * 删除型号列表信息
     *
     * @param modelId 型号列表主键
     * @return 结果
     */
    public int deleteSmModelByModelId(Long modelId);

    /**
     * 条件查询数量
     * @param dto 查询条件
     * @return 结果
     */
    Integer selectCount(SmModelQuery dto);

    /**
     * 逻辑删除
     */
    int logicDelete(List<Long> modelIds);

    /**
     * 根据型号查询数据
     */
    SmModelVO selectByModel(String model);

    /**
     * 创建初始型号
     */
    int addInitModel(IotDeviceInfo deviceInfo);

    SmModelVO selectOne(SmModelQuery query);
}
